
.text-primary, .text-primary:hover{
    color: #1D62F0;
}
.text-info, .text-info:hover{
    color: #109CFF;
}
.text-success, .text-success:hover{
    color: #0C9C14;
}
.text-warning, .text-warning:hover{
    color: #ED8D00;
}
.text-danger, .text-danger:hover{
    color: #EE2D20;
}
.modal-header {
    border: 0 none;
    
}
.wizard-card .wizard-header h3 b{
    text-transform: uppercase;
}
.tooltip {
    font-size: 14px;
    font-weight: bold;
}
.tooltip-arrow{
    display: none;
    opacity: 0;
}
.tooltip-inner {
    background-color: #FAE6A4;
    border-radius: 4px;
    box-shadow: 0 1px 13px rgba(0, 0, 0, 0.14), 0 0 0 1px rgba(115, 71, 38, 0.23);
    color: #734726;
    max-width: 200px;
    padding: 6px 10px;
    text-align: center;
    text-decoration: none;
}
.tooltip-inner:after {
    content: "";
    display: inline-block;
    left: 100%;
    margin-left: -56%;
    position: absolute;
}
.tooltip-inner:before {
    content: "";
    display: inline-block;
    left: 100%;
    margin-left: -56%;
    position: absolute;
}
.tooltip.top {
    margin-top: -11px;
    padding: 0;
}
.tooltip.top .tooltip-inner:after {
    border-top: 11px solid #FAE6A4;
    border-left: 11px solid rgba(0, 0, 0, 0);
    border-right: 11px solid rgba(0, 0, 0, 0);
    bottom: -10px;
}
.tooltip.top .tooltip-inner:before {
    border-top: 11px solid rgba(0, 0, 0, 0.2);
    border-left: 11px solid rgba(0, 0, 0, 0);
    border-right: 11px solid rgba(0, 0, 0, 0);
    bottom: -11px;
}
.tooltip.bottom {
    margin-top: 11px;
    padding: 0;
}
.tooltip.bottom .tooltip-inner:after {
    border-bottom: 11px solid #FAE6A4;
    border-left: 11px solid rgba(0, 0, 0, 0);
    border-right: 11px solid rgba(0, 0, 0, 0);
    top: -10px;
}
.tooltip.bottom .tooltip-inner:before {
    border-bottom: 11px solid rgba(0, 0, 0, 0.2);
    border-left: 11px solid rgba(0, 0, 0, 0);
    border-right: 11px solid rgba(0, 0, 0, 0);
    top: -11px;
}
.tooltip.left{
    margin-left: -11px;
    padding: 0;
}
.tooltip.left .tooltip-inner:after {
    border-left: 11px solid #FAE6A4;
    border-top: 11px solid rgba(0, 0, 0, 0);
    border-bottom: 11px solid rgba(0, 0, 0, 0);
    right: -10px;
    left: auto;
    margin-left: 0;
}
.tooltip.left .tooltip-inner:before {
    border-left: 11px solid rgba(0, 0, 0, 0.2);
    border-top: 11px solid rgba(0, 0, 0, 0);
    border-bottom: 11px solid rgba(0, 0, 0, 0);
    right: -11px;
    left: auto;
    margin-left: 0;
}
.tooltip.right{
    margin-left: 11px;
    padding: 0;
}
.tooltip.right .tooltip-inner:after {
    border-right: 11px solid #FAE6A4;
    border-top: 11px solid rgba(0, 0, 0, 0);
    border-bottom: 11px solid rgba(0, 0, 0, 0);
    left: -10px;
    top: 0;
    margin-left: 0;
}
.tooltip.right .tooltip-inner:before {
    border-right: 11px solid rgba(0, 0, 0, 0.2);
    border-top: 11px solid rgba(0, 0, 0, 0);
    border-bottom: 11px solid rgba(0, 0, 0, 0);
    left: -11px;
    top: 0;
    margin-left: 0;
}

.logo-container{
    left: 50px;
    position: absolute;
    top: 20px;
     z-index: 3;
}
.logo-container .logo{
    overflow: hidden;
    border-radius: 50%;
    border: 1px solid #333333;
    width: 60px; 
    float: left;
}
.logo-container .brand{
    font-size: 18px;
    color: #FFFFFF;
    line-height: 20px;
    float: left;
    margin-left: 10px;
    margin-top: 10px;
    width: 60px
}


.card{
    background-color: #FFFFFF;
    padding: 10px 0 20px;
    width: 100%;
}

.pick-class-label{
    border-radius: 8px;
    color: #ffffff;
    cursor: pointer;
    display: inline;
    font-size: 75%;
    font-weight: bold;
    line-height: 1;
    margin-right: 10px;
    padding: 15px 23px;
    text-align: center;
    vertical-align: baseline;
    white-space: nowrap;
}

/*      Here the code for the wizard           */

label{
    font-weight: 400;
}

.image-container{
    height: 100%;
    background-position: center center;
    background-size: cover;
}


.wizard-container{
   padding-top: 30px;
    z-index: 3;
}
.wizard-card{
padding: 10px 0px; 
border: 1px solid #eee;
    transition: all 0.2s;
    -webkit-transition: all 0.2s;
}
.wizard-card .picture-container{
    position: relative;
    cursor: pointer;
    text-align: center;
}
.wizard-card .picture{
width: 220px;
height: 230px;
background-color: #808080;
border: 4px solid #CCC;
color: #FFF;
border-radius: 4px;
margin: 35px auto;
    overflow: hidden;
    transition: all 0.2s;
    -webkit-transition: all 0.2s;
}
.wizard-card .picture:hover{
    border-color: #2ca8ff;
}
.wizard-card.ct-wizard-azzure .picture:hover{
    border-color: #2CA8FF;
}
.wizard-card.ct-wizard-green .picture:hover{
    border-color: #05ae0e;
}
.wizard-card.ct-wizard-blue .picture:hover{
    border-color: #3472f7;
}
.wizard-card.ct-wizard-orange .picture:hover{
    border-color: #FDC600;
}
.wizard-card.ct-wizard-red .picture:hover{
    border-color: #ff3b30;
}
.wizard-card .picture input[type="file"] {
    cursor: pointer;
    display: block;
    height: 100%;
    left: 0;
    opacity: 0 !important;
    position: absolute;
    top: 0;
    width: 100%;
}

.wizard-card .picture-src{
    width: 100%;
    
}
.wizard-card .tab-content{
    min-height: 340px;
    padding: 20px 10px;
}

.wizard-card .wizard-footer{
    padding: 0 10px;
}

.wizard-card .disabled{
    display: none;
}

.wizard-card .wizard-header h3{
    font-weight: 200;
    text-align: center;
}
.wizard-card .nav-pills > li{
    text-align: center;
}
.wizard-card .nav-pills > li a {
    border: 0 !important;
    text-transform: uppercase;
    background-color: #999999;
    color: #FFFFFF !important;
    font-size: 12px;
}
.wizard-card.ct-wizard-green .nav-pills > li.active a{
    background-color: #05ae0e;
}
.wizard-card.ct-wizard-azzure .nav-pills > li.active a{
    background-color: #2CA8FF;
}
.wizard-card.ct-wizard-blue .nav-pills > li.active a{
    background-color: #3472f7;
}
.wizard-card.ct-wizard-orange .nav-pills > li.active a{
    background-color: #FDC600;
}
.wizard-card.ct-wizard-red .nav-pills > li.active a{
    background-color: #ff3b30;
}

.wizard-card .nav-pills > li > a:hover, .wizard-card .nav-pills > li > a:focus{
    background-color: #999999;
    cursor: default;
} 
.wizard-card .btn{
    text-transform: uppercase;
}
.wizard-card .nav-pills > li:first-child > a {
    border-radius: 0;
    margin: 0;
}
.wizard-card .nav-pills > li:last-child > a{
    border-radius: 0;
}
.wizard-card .info-text{
    text-align: center;
    font-weight: 300;
    margin: 10px 0 30px;
}
.wizard-card .choice{
    text-align: center;
    cursor: pointer;
    margin-top: 20px;
}
.wizard-card .choice .icon{
   text-align: center;
   vertical-align: middle;
   height: 116px;
   width: 116px;
   border-radius: 50%;
   background-color: #999999;
   color: #FFFFFF;
   margin: 0 auto 20px;
   border: 4px solid #CCCCCC;
   transition: all 0.2s;
   -webkit-transition: all 0.2s;
}
.wizard-card .choice i{
    font-size: 30px;
    line-height: 111px;
}

.wizard-card .choice:hover .icon, .wizard-card .choice.active .icon{
    border-color: #2ca8ff;
}

.wizard-card.ct-wizard-azzure .choice:hover .icon, .wizard-card.ct-wizard-azzure .choice.active .icon{
    border-color: #2CA8FF;
}
.wizard-card.ct-wizard-blue .choice:hover .icon, .wizard-card.ct-wizard-blue .choice.active .icon{
    border-color: #3472f7;
}
.wizard-card.ct-wizard-green .choice:hover .icon, .wizard-card.ct-wizard-green .choice.active .icon{
    border-color: #05ae0e;
}
.wizard-card.ct-wizard-orange .choice:hover .icon, .wizard-card.ct-wizard-orange .choice.active .icon{
    border-color: #FDC600;
}
.wizard-card.ct-wizard-red .choice:hover .icon, .wizard-card.ct-wizard-red .choice.active .icon{
    border-color: #ff3b30;
}

.wizard-card .choice input[type="radio"],
.wizard-card .choice input[type="checkbox"]{
    position: absolute;
    left: -10000px;
    z-index: -1;
}
.wizard-card .btn-finish{
    display: none;
}

.wizard-card .description{
    color: #999999;
    font-size: 14px;
}
